@@ -8,13 +8,14 @@
 
 use strict;
 use warnings;
-use Ham::Resources::HamQTH;
+use lib('../lib/Ham/Resources/');
+use HamQTH;
 
-my $username = ""; # put your username HamQTH account here
-my $password = ""; # put your password HamQTH here
+my $username = "ea3hmb"; # put your username HamQTH account here
+my $password = "km3171g"; # put your password HamQTH here
 my $callsign = $ARGV[0]; # callsign to search how command line argument
 my $strip_html = 1; # 1 = text plain, 0 = HTML code
-
+my $bio;
 my $qth = Ham::Resources::HamQTH->new(
 	callsign => $callsign,
 	username => $username,
@@ -26,13 +27,18 @@ my $qth = Ham::Resources::HamQTH->new(
 print "BIO for: $callsign\n";
 print "-"x40;
 print "\n";
-my $bio = $qth->get_bio;
+
+if (length($callsign) <= 3) {
+	$bio = $qth->get_dxcc;
+} else {
+	$bio = $qth->get_bio;
+}
 foreach (sort keys %{$bio}){
 	print $_.": ".$bio->{$_}."\n";
 }
 
 # print a specific info
-print "\n\nCallsign found: ".$bio->{callsign}."\n" if (!$bio->{error});
+print "\n\nCallsign found: ".$bio->{callsign}."\n" if (!$bio->{error} && $bio->{callsign});
 print "\n";
 
 # get a list of available elements
